@@ -160,7 +160,21 @@ class BHunters(Karton):
 
         db = client[db]
         return db    
-
+    def checklinksexist(self,subdomain,links):
+        collection=self.db["domains"]
+        missing_links=[]
+        if isinstance(links,str):
+            links=links.splitlines()
+        existing_document = collection.find_one({"Domain": subdomain})
+        if existing_document is None:
+            self.log.error("No document found for the specified domain.")
+            
+        else:
+            existing_links = existing_document.get("ScanLinks", {}).get(self.identity, [])
+            missing_links = [link for link in links if link not in existing_links]
+            if missing_links:
+                collection.update_one({"Domain": subdomain}, {"$push": {f"ScanLinks.{self.identity}": {"$each": missing_links}}})
+        return missing_links    
     def encode_filename(self, url_or_path):
         """
         Encodes a URL or path to be a valid filename by replacing unsupported characters.
